IcmpRxCounters

Struct IcmpRxCounters 

pub struct IcmpRxCounters<I: IcmpCountersIpExt, C: CounterRepr = Counter> {
    pub error: C,
    pub error_delivered_to_transport_layer: C,
    pub error_delivered_to_socket: C,
    pub echo_request: C,
    pub echo_reply: C,
    pub timestamp_request: C,
    pub dest_unreachable: <I::DestUnreachableCounters as CounterCollectionSpec>::CounterCollection<C>,
    pub time_exceeded: <I::TimeExceededCounters as CounterCollectionSpec>::CounterCollection<C>,
    pub parameter_problem: <I::ParameterProblemCounters as CounterCollectionSpec>::CounterCollection<C>,
    pub packet_too_big: C,
    pub queue_full: C,
}
ICMP rx path counters.

Fields

error: C

Count of error messages received.

error_delivered_to_transport_layer: C

Count of error messages delivered to the transport layer.

error_delivered_to_socket: C

Count of error messages delivered to a socket.

echo_request: C

Count of echo request messages received.

echo_reply: C

Count of echo reply messages received.

timestamp_request: C

Count of timestamp request messages received.

dest_unreachable: <I::DestUnreachableCounters as CounterCollectionSpec>::CounterCollection<C>

Count of destination unreachable messages received.

time_exceeded: <I::TimeExceededCounters as CounterCollectionSpec>::CounterCollection<C>

Count of time exceeded messages received.

parameter_problem: <I::ParameterProblemCounters as CounterCollectionSpec>::CounterCollection<C>

Count of parameter problem messages received.

packet_too_big: C

Count of packet too big messages received.

queue_full: C

Count of ICMP Echo datagrams that could not be delivered to the socket because its receive buffer was full.