EchoTransportContextMarker

Trait EchoTransportContextMarker 

pub trait EchoTransportContextMarker { }
A marker trait to prevent integration from creating a recursive loop when handling Echo sockets.

This is a requirement for InnerIcmpContext::EchoTransportContext which disallows the integration layer from using IcmpIpTransportContext as the associated type, which would create a recursive loop.

By not implementing this trait for [IcmpIpTransporContext] we prevent the mistake.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors