InnerIcmpv4Context

Trait InnerIcmpv4Context 

pub trait InnerIcmpv4Context<BC: IcmpBindingsTypes>: InnerIcmpContext<Ipv4, BC> {
    // Required method
    fn should_send_timestamp_reply(&self) -> bool;
}
The execution context for ICMPv4.

InnerIcmpv4Context is a shorthand for a larger collection of traits.

Required Methods

fn should_send_timestamp_reply(&self) -> bool

Returns true if a timestamp reply may be sent.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors