LinkResolutionContext

Trait LinkResolutionContext 

pub trait LinkResolutionContext<D: LinkDevice> {
    type Notifier: LinkResolutionNotifier<D>;
}
An execution context that allows creating link resolution notifiers.

Required Associated Types

type Notifier: LinkResolutionNotifier<D>

A notifier held by core that can be used to inform interested parties of the result of link address resolution.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<D: LinkDevice, Id, Event: Debug, State, FrameMeta> LinkResolutionContext<D> for FakeBindingsCtx<Id, Event, State, FrameMeta>

Implementors