pub trait IpRoutingBindingsTypes {
type RoutingTableId: Send + Sync + Debug + 'static;
}Expand description
Bindings types for IP routing.
Required Associated Types
Sourcetype RoutingTableId: Send + Sync + Debug + 'static
type RoutingTableId: Send + Sync + Debug + 'static
An opaque type that represents a routing table ID from the Bindings. The Bindings implementation is responsible for providing a unique ID for each routing table.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".